@@ -10,16 +10,19 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+from __future__ import annotations
 
 from abc import ABC, abstractmethod
 
+import braket.circuits.circuit as cir
+
 
 class CircuitDiagram(ABC):
     """A class that builds circuit diagrams."""
 
     @staticmethod
     @abstractmethod
-    def build_diagram(circuit) -> str:
+    def build_diagram(circuit: cir.Circuit) -> str:
         """
         Build a diagram for the specified `circuit`.
 
