@@ -14,13 +14,20 @@
 from __future__ import annotations
 
 import re
-from typing import List
+from functools import reduce
+from typing import List, Union
 
 import braket.ir.jaqcd as ir
 from braket.circuits import circuit
+from braket.circuits.free_parameter import FreeParameter
 from braket.circuits.observable import Observable
+from braket.circuits.observables import Sum
 from braket.circuits.qubit_set import QubitSet, QubitSetInput
-from braket.circuits.result_type import ObservableResultType, ResultType
+from braket.circuits.result_type import (
+    ObservableParameterResultType,
+    ObservableResultType,
+    ResultType,
+)
 from braket.circuits.serialization import IRType, OpenQASMSerializationProperties
 
 """
@@ -119,7 +126,7 @@ class DensityMatrix(ResultType):
 
     def _to_openqasm(self, serialization_properties: OpenQASMSerializationProperties) -> str:
         if not self.target:
-            return "#pragma braket result density_matrix"
+            return "#pragma braket result density_matrix all"
         targets = ", ".join(
             serialization_properties.format_target(int(target)) for target in self.target
         )
@@ -162,6 +169,110 @@ class DensityMatrix(ResultType):
 ResultType.register_result_type(DensityMatrix)
 
 
+class AdjointGradient(ObservableParameterResultType):
+    """
+    The gradient of the expectation value of the provided observable, applied to target,
+    with respect to the given parameter.
+    """
+
+    def __init__(
+        self,
+        observable: Observable,
+        target: List[QubitSetInput] = None,
+        parameters: List[Union[str, FreeParameter]] = None,
+    ):
+        """
+        Args:
+            observable (Observable): The expectation value of this observable is the function
+                against which parameters in the gradient are differentiated.
+            target (List[QubitSetInput]): Target qubits that the result type is requested for.
+                Each term in the target list should have the same number of qubits as the
+                corresponding term in the observable. Default is `None`, which means the
+                observable must operate only on 1 qubit and it is applied to all qubits
+                in parallel.
+            parameters (List[Union[str, FreeParameter]]): The free parameters in the circuit to
+                differentiate with respect to. Default: `all`.
+
+        Raises:
+            ValueError: If the observable's qubit count does not equal the number of target
+                qubits, or if `target=None` and the observable's qubit count is not 1.
+
+        Examples:
+            >>> ResultType.AdjointGradient(observable=Observable.Z(),
+                                        target=0, parameters=["alpha", "beta"])
+
+            >>> tensor_product = Observable.Y() @ Observable.Z()
+            >>> hamiltonian = Observable.Y() @ Observable.Z() + Observable.H()
+            >>> ResultType.AdjointGradient(
+            >>>     observable=tensor_product,
+            >>>     target=[[0, 1], [2]],
+            >>>     parameters=["alpha", "beta"],
+            >>> )
+        """
+
+        if isinstance(observable, Sum):
+            target_qubits = reduce(QubitSet.union, map(QubitSet, target), QubitSet())
+        else:
+            target_qubits = QubitSet(target)
+
+        super().__init__(
+            ascii_symbols=[f"AdjointGradient({observable.ascii_symbols[0]})"] * len(target_qubits),
+            observable=observable,
+            target=target,
+            parameters=parameters,
+        )
+
+    def _to_openqasm(self, serialization_properties: OpenQASMSerializationProperties) -> str:
+        observable_ir = self.observable.to_ir(
+            target=self.target,
+            ir_type=IRType.OPENQASM,
+            serialization_properties=serialization_properties,
+        )
+
+        pragma_parameters = ", ".join(self.parameters) if self.parameters else "all"
+
+        return (
+            f"#pragma braket result adjoint_gradient "
+            f"expectation({observable_ir}) {pragma_parameters}"
+        )
+
+    @staticmethod
+    @circuit.subroutine(register=True)
+    def adjoint_gradient(
+        observable: Observable,
+        target: List[QubitSetInput] = None,
+        parameters: List[Union[str, FreeParameter]] = None,
+    ) -> ResultType:
+        """Registers this function into the circuit class.
+
+        Args:
+            observable (Observable): The expectation value of this observable is the function
+                against which parameters in the gradient are differentiated.
+            target (List[QubitSetInput]): Target qubits that the result type is requested for.
+                Each term in the target list should have the same number of qubits as the
+                corresponding term in the observable. Default is `None`, which means the
+                observable must operate only on 1 qubit and it is applied to all qubits
+                in parallel.
+            parameters (List[Union[str, FreeParameter]]): The free parameters in the circuit to
+                differentiate with respect to. Default: `all`.
+
+        Returns:
+            ResultType: gradient computed via adjoint differentiation as a requested result type
+
+        Examples:
+            >>> alpha, beta = FreeParameter('alpha'), FreeParameter('beta')
+            >>> circ = Circuit().h(0).h(1).rx(0, alpha).yy(0, 1, beta).adjoint_gradient(
+            >>>     observable=Observable.Z(), target=[0], parameters=[alpha, beta]
+            >>> )
+        """
+        return ResultType.AdjointGradient(
+            observable=observable, target=target, parameters=parameters
+        )
+
+
+ResultType.register_result_type(AdjointGradient)
+
+
 class Amplitude(ResultType):
     """
     The amplitude of the specified quantum states as a requested result type.
