@@ -14,6 +14,11 @@
 import pytest
 
 from braket.circuits import Gate, Instruction, Noise, Qubit, QubitSet, compiler_directives
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    QubitReferenceType,
+)
 
 
 @pytest.fixture
@@ -115,17 +120,23 @@ def test_equality():
 def test_to_ir():
     expected_target = QubitSet([0, 1])
     expected_ir = "foo bar value"
+    expected_ir_type = IRType.OPENQASM
+    expected_serialization_properties = OpenQASMSerializationProperties(
+        qubit_reference_type=QubitReferenceType.PHYSICAL
+    )
 
     class FooGate(Gate):
         def __init__(self):
             super().__init__(qubit_count=2, ascii_symbols=["foo", "bar"])
 
-        def to_ir(self, target):
+        def to_ir(self, target, ir_type, serialization_properties):
             assert target == expected_target
+            assert ir_type == expected_ir_type
+            assert serialization_properties == expected_serialization_properties
             return expected_ir
 
     instr = Instruction(FooGate(), expected_target)
-    assert instr.to_ir() == expected_ir
+    assert instr.to_ir(expected_ir_type, expected_serialization_properties) == expected_ir
 
 
 def test_copy_creates_new_object(instr):
